==> 1.0.4.tar.gz: lib/amazingneoicons.dart <==
import 'package:flutter/material.dart';

/// Amazing Neo icon pack (112 icons)
class _AmazingNeoIcons extends IconData {
  /// construct IconData
  const _AmazingNeoIcons(int codePoint)
      : super(codePoint,
            fontFamily: 'amazingneoicons',
            fontPackage: 'iconforest_amazingneoicons');
}

/// constants link to font code point
class AmazingNeoIcons {
  /// No need for constructor. All properties are static
  const AmazingNeoIcons._();

  /// map IconData named abacus to code point 0xf101
  static const IconData abacus = _AmazingNeoIcons(0xf101);

  /// map IconData named ac to code point 0xf102
  static const IconData ac = _AmazingNeoIcons(0xf102);

  /// map IconData named accessible to code point 0xf103
  static const IconData accessible = _AmazingNeoIcons(0xf103);

  /// map IconData named accounts to code point 0xf104
  static const IconData accounts = _AmazingNeoIcons(0xf104);

  /// map IconData named acorn to code point 0xf105
  static const IconData acorn = _AmazingNeoIcons(0xf105);

  /// map IconData named addressbook to code point 0xf106
  static const IconData addressbook = _AmazingNeoIcons(0xf106);

  /// map IconData named addresscard to code point 0xf107
  static const IconData addresscard = _AmazingNeoIcons(0xf107);

  /// map IconData named adjust to code point 0xf108
  static const IconData adjust = _AmazingNeoIcons(0xf108);

  /// map IconData named airplane_alt to code point 0xf109
  static const IconData airplane_alt = _AmazingNeoIcons(0xf109);

  /// map IconData named airplane to code point 0xf10a
  static const IconData airplane = _AmazingNeoIcons(0xf10a);

  /// map IconData named alarm_clock to code point 0xf10b
  static const IconData alarm_clock = _AmazingNeoIcons(0xf10b);

  /// map IconData named alarm_exclamation to code point 0xf10c
  static const IconData alarm_exclamation = _AmazingNeoIcons(0xf10c);

  /// map IconData named alarm_plus to code point 0xf10d
  static const IconData alarm_plus = _AmazingNeoIcons(0xf10d);

  /// map IconData named alarm_snooze to code point 0xf10e
  static const IconData alarm_snooze = _AmazingNeoIcons(0xf10e);

  /// map IconData named align_cente to code point 0xf10f
  static const IconData align_cente = _AmazingNeoIcons(0xf10f);

  /// map IconData named align_justify to code point 0xf110
  static const IconData align_justify = _AmazingNeoIcons(0xf110);

  /// map IconData named align_left to code point 0xf111
  static const IconData align_left = _AmazingNeoIcons(0xf111);

  /// map IconData named align_right to code point 0xf112
  static const IconData align_right = _AmazingNeoIcons(0xf112);

  /// map IconData named align_slash to code point 0xf113
  static const IconData align_slash = _AmazingNeoIcons(0xf113);

  /// map IconData named ambulance to code point 0xf114
  static const IconData ambulance = _AmazingNeoIcons(0xf114);

  /// map IconData named analytics to code point 0xf115
  static const IconData analytics = _AmazingNeoIcons(0xf115);

  /// map IconData named anchor to code point 0xf116
  static const IconData anchor = _AmazingNeoIcons(0xf116);

  /// map IconData named angle_double_down_circle to code point 0xf117
  static const IconData angle_double_down_circle = _AmazingNeoIcons(0xf117);

  /// map IconData named angle_double_down_square to code point 0xf118
  static const IconData angle_double_down_square = _AmazingNeoIcons(0xf118);

  /// map IconData named angle_double_down to code point 0xf119
  static const IconData angle_double_down = _AmazingNeoIcons(0xf119);

  /// map IconData named angle_double_left_circle to code point 0xf11a
  static const IconData angle_double_left_circle = _AmazingNeoIcons(0xf11a);

  /// map IconData named angle_double_left_square to code point 0xf11b
  static const IconData angle_double_left_square = _AmazingNeoIcons(0xf11b);

  /// map IconData named angle_double_left to code point 0xf11c
  static const IconData angle_double_left = _AmazingNeoIcons(0xf11c);

  /// map IconData named angle_double_right_circle to code point 0xf11d
  static const IconData angle_double_right_circle = _AmazingNeoIcons(0xf11d);

  /// map IconData named angle_double_right_square to code point 0xf11e
  static const IconData angle_double_right_square = _AmazingNeoIcons(0xf11e);

  /// map IconData named angle_double_right to code point 0xf11f
  static const IconData angle_double_right = _AmazingNeoIcons(0xf11f);

  /// map IconData named angle_double_up_circle to code point 0xf120
  static const IconData angle_double_up_circle = _AmazingNeoIcons(0xf120);

  /// map IconData named angle_double_up_square to code point 0xf121
  static const IconData angle_double_up_square = _AmazingNeoIcons(0xf121);

  /// map IconData named angle_double_up to code point 0xf122
  static const IconData angle_double_up = _AmazingNeoIcons(0xf122);

  /// map IconData named angle_down_alt_circlebacus to code point 0xf123
  static const IconData angle_down_alt_circlebacus = _AmazingNeoIcons(0xf123);

  /// map IconData named angle_down_alt_double_circle to code point 0xf124
  static const IconData angle_down_alt_double_circle = _AmazingNeoIcons(0xf124);

  /// map IconData named angle_down_alt_double_square to code point 0xf125
  static const IconData angle_down_alt_double_square = _AmazingNeoIcons(0xf125);

  /// map IconData named angle_down_alt_double to code point 0xf126
  static const IconData angle_down_alt_double = _AmazingNeoIcons(0xf126);

  /// map IconData named angle_down_alt_square to code point 0xf127
  static const IconData angle_down_alt_square = _AmazingNeoIcons(0xf127);

  /// map IconData named angle_down_alt to code point 0xf128
  static const IconData angle_down_alt = _AmazingNeoIcons(0xf128);

  /// map IconData named angle_down_circle to code point 0xf129
  static const IconData angle_down_circle = _AmazingNeoIcons(0xf129);

  /// map IconData named angle_down_square to code point 0xf12a
  static const IconData angle_down_square = _AmazingNeoIcons(0xf12a);

  /// map IconData named angle_dow to code point 0xf12b
  static const IconData angle_dow = _AmazingNeoIcons(0xf12b);

  /// map IconData named angle_left_alt_circle to code point 0xf12c
  static const IconData angle_left_alt_circle = _AmazingNeoIcons(0xf12c);

  /// map IconData named angle_left_alt_double to code point 0xf12d
  static const IconData angle_left_alt_double = _AmazingNeoIcons(0xf12d);

  /// map IconData named angle_left_alt_doublet_circle to code point 0xf12e
  static const IconData angle_left_alt_doublet_circle =
      _AmazingNeoIcons(0xf12e);

  /// map IconData named angle_left_alt_doublet_square to code point 0xf12f
  static const IconData angle_left_alt_doublet_square =
      _AmazingNeoIcons(0xf12f);

  /// map IconData named angle_left_alt_square to code point 0xf130
  static const IconData angle_left_alt_square = _AmazingNeoIcons(0xf130);

  /// map IconData named angle_left_alt to code point 0xf131
  static const IconData angle_left_alt = _AmazingNeoIcons(0xf131);

  /// map IconData named angle_left_circle to code point 0xf132
  static const IconData angle_left_circle = _AmazingNeoIcons(0xf132);

  /// map IconData named angle_left_square to code point 0xf133
  static const IconData angle_left_square = _AmazingNeoIcons(0xf133);

  /// map IconData named angle_left to code point 0xf134
  static const IconData angle_left = _AmazingNeoIcons(0xf134);

  /// map IconData named angle_right_alt_circle to code point 0xf135
  static const IconData angle_right_alt_circle = _AmazingNeoIcons(0xf135);

  /// map IconData named angle_right_alt_double_circle to code point 0xf136
  static const IconData angle_right_alt_double_circle =
      _AmazingNeoIcons(0xf136);

  /// map IconData named angle_right_alt_double_square to code point 0xf137
  static const IconData angle_right_alt_double_square =
      _AmazingNeoIcons(0xf137);

  /// map IconData named angle_right_alt_double to code point 0xf138
  static const IconData angle_right_alt_double = _AmazingNeoIcons(0xf138);

  /// map IconData named beach to code point 0xf1cb
  static const IconData beach = _AmazingNeoIcons(0xf1cb);

  /// map IconData named archive to code point 0xf147
  static const IconData archive = _AmazingNeoIcons(0xf147);

  /// map IconData named auto_rickshaw to code point 0xf17f
  static const IconData auto_rickshaw = _AmazingNeoIcons(0xf17f);

  /// map IconData named at to code point 0xf17e
  static const IconData at = _AmazingNeoIcons(0xf17e);

  /// map IconData named baby to code point 0xf188
  static const IconData baby = _AmazingNeoIcons(0xf188);

  /// map IconData named availability to code point 0xf181
  static const IconData availability = _AmazingNeoIcons(0xf181);

  /// map IconData named backpac to code point 0xf189
  static const IconData backpac = _AmazingNeoIcons(0xf189);

  /// map IconData named barcode to code point 0xf1ad
  static const IconData barcode = _AmazingNeoIcons(0xf1ad);

  /// map IconData named battery_empty to code point 0xf1bf
  static const IconData battery_empty = _AmazingNeoIcons(0xf1bf);

  /// map IconData named battery_full to code point 0xf1c1
  static const IconData battery_full = _AmazingNeoIcons(0xf1c1);

  /// map IconData named book to code point 0xf106
  static const IconData book = _AmazingNeoIcons(0xf106);

  /// map IconData named birthday_cake to code point 0xf1d8
  static const IconData birthday_cake = _AmazingNeoIcons(0xf1d8);

  /// map IconData named bed_double to code point 0xf1cd
  static const IconData bed_double = _AmazingNeoIcons(0xf1cd);

  /// map IconData named bitcoin to code point 0xf1dd
  static const IconData bitcoin = _AmazingNeoIcons(0xf1dd);

  /// map IconData named bicycle to code point 0xff1d6
  static const IconData bicycle = _AmazingNeoIcons(0xff1d6);

  /// map IconData named bus to code point 0xf228
  static const IconData bus = _AmazingNeoIcons(0xf228);

  /// map IconData named calculator_sign to code point 0xf22b
  static const IconData calculator_sign = _AmazingNeoIcons(0xf22b);

  /// map IconData named car to code point 0xf243
  static const IconData car = _AmazingNeoIcons(0xf243);

  /// map IconData named an_car_wash to code point 0xf248
  static const IconData an_car_wash = _AmazingNeoIcons(0xf248);

  /// map IconData named cart to code point 0xf24c
  static const IconData cart = _AmazingNeoIcons(0xf24c);

  /// map IconData named cart_plus to code point 0xf250
  static const IconData cart_plus = _AmazingNeoIcons(0xf250);

  /// map IconData named chart_line to code point 0xf25d
  static const IconData chart_line = _AmazingNeoIcons(0xf25d);

  /// map IconData named chart_bar to code point 0xf25d
  static const IconData chart_bar = _AmazingNeoIcons(0xf25d);

  /// map IconData named city to code point 0xf272
  static const IconData city = _AmazingNeoIcons(0xf272);

  /// map IconData named cloud_upload to code point 0xf288
  static const IconData cloud_upload = _AmazingNeoIcons(0xf288);

  /// map IconData named coffee to code point 0xf295
  static const IconData coffee = _AmazingNeoIcons(0xf295);

  /// map IconData named danger to code point 0xf2e7
  static const IconData danger = _AmazingNeoIcons(0xf2e7);

  /// map IconData named dance to code point 0xf2e6
  static const IconData dance = _AmazingNeoIcons(0xf2e6);

  /// map IconData named diamond to code point 0xf2f1
  static const IconData diamond = _AmazingNeoIcons(0xf2f1);

  /// map IconData named dice to code point 0xf2f2
  static const IconData dice = _AmazingNeoIcons(0xf2f2);

  /// map IconData named destinatio to code point 0xf2ed
  static const IconData destinatio = _AmazingNeoIcons(0xf2ed);

  /// map IconData named eiffel_tower to code point 0xf30f
  static const IconData eiffel_tower = _AmazingNeoIcons(0xf30f);

  /// map IconData named fingerprint to code point 0xf36f
  static const IconData fingerprint = _AmazingNeoIcons(0xf36f);

  /// map IconData named galaxy to code point 0xf396
  static const IconData galaxy = _AmazingNeoIcons(0xf396);

  /// map IconData named glass_chairs to code point 0xf39f
  static const IconData glass_chairs = _AmazingNeoIcons(0xf39f);

  /// map IconData named gift to code point 0xf39d
  static const IconData gift = _AmazingNeoIcons(0xf39d);

  /// map IconData named gift_card to code point 0xf39d
  static const IconData gift_card = _AmazingNeoIcons(0xf39d);

  /// map IconData named graduation_cap to code point 0xf3ae
  static const IconData graduation_cap = _AmazingNeoIcons(0xf3ae);

  /// map IconData named guitar to code point 0xf3bc
  static const IconData guitar = _AmazingNeoIcons(0xf3bc);

  /// map IconData named hairdryer to code point 0xf3c6
  static const IconData hairdryer = _AmazingNeoIcons(0xf3c6);

  /// map IconData named halloween to code point 0xf3c7
  static const IconData halloween = _AmazingNeoIcons(0xf3c7);

  /// map IconData named hand to code point 0xf3d1
  static const IconData hand = _AmazingNeoIcons(0xf3d1);

  /// map IconData named hand_clap to code point 0xf3ca
  static const IconData hand_clap = _AmazingNeoIcons(0xf3ca);

  /// map IconData named kaaba to code point 0xf413
  static const IconData kaaba = _AmazingNeoIcons(0xf413);

  /// map IconData named jet to code point 0xf412
  static const IconData jet = _AmazingNeoIcons(0xf412);

  /// map IconData named key to code point 0xf414
  static const IconData key = _AmazingNeoIcons(0xf414);

  /// map IconData named laptop to code point 0xf420
  static const IconData laptop = _AmazingNeoIcons(0xf420);

  /// map IconData named laptop_code to code point 0xf41f
  static const IconData laptop_code = _AmazingNeoIcons(0xf41f);

  /// map IconData named landmark to code point 0xf41d
  static const IconData landmark = _AmazingNeoIcons(0xf41d);

  /// map IconData named lightbulb_on to code point 0xf42d
  static const IconData lightbulb_on = _AmazingNeoIcons(0xf42d);

  /// map IconData named list to code point 0xf43d
  static const IconData list = _AmazingNeoIcons(0xf43d);

  /// map IconData named lock to code point 0xf442
  static const IconData lock = _AmazingNeoIcons(0xf442);

  /// map IconData named lock_open to code point 0xf444
  static const IconData lock_open = _AmazingNeoIcons(0xf444);

  /// map IconData named login to code point 0xf449
  static const IconData login = _AmazingNeoIcons(0xf449);

  /// map IconData named logout to code point 0xf44b
  static const IconData logout = _AmazingNeoIcons(0xf44b);

  /// map IconData named logout_alt to code point 0xf44a
  static const IconData logout_alt = _AmazingNeoIcons(0xf44a);

  /// map IconData named london_eye to code point 0xf44c
  static const IconData london_eye = _AmazingNeoIcons(0xf44c);
}

==> 1.1.6.tar.gz: lib/amazingneoicons.dart <==
import 'package:flutter/material.dart';

/// Amazing Neo icon pack (112 icons)
class _AmazingNeoIcons extends IconData {
  const _AmazingNeoIcons(int codePoint)
      : super(codePoint,
            fontFamily: 'amazingneoicons', fontPackage: 'icon_forest');
}

/// constants link to font code point
class AmazingNeoIcons {
  /// map abacus to code point 0xf101
  static const IconData abacus = _AmazingNeoIcons(0xf101);

  /// map ac to code point 0xf102
  static const IconData ac = _AmazingNeoIcons(0xf102);

  /// map accessible to code point 0xf103
  static const IconData accessible = _AmazingNeoIcons(0xf103);

  /// map accounts to code point 0xf104
  static const IconData accounts = _AmazingNeoIcons(0xf104);

  /// map acorn to code point 0xf105
  static const IconData acorn = _AmazingNeoIcons(0xf105);

  /// map addressbook to code point 0xf106
  static const IconData addressbook = _AmazingNeoIcons(0xf106);

  /// map addresscard to code point 0xf107
  static const IconData addresscard = _AmazingNeoIcons(0xf107);

  /// map adjust to code point 0xf108
  static const IconData adjust = _AmazingNeoIcons(0xf108);

  /// map airplane_alt to code point 0xf109
  static const IconData airplane_alt = _AmazingNeoIcons(0xf109);

  /// map airplane to code point 0xf10a
  static const IconData airplane = _AmazingNeoIcons(0xf10a);

  /// map alarm_clock to code point 0xf10b
  static const IconData alarm_clock = _AmazingNeoIcons(0xf10b);

  /// map alarm_exclamation to code point 0xf10c
  static const IconData alarm_exclamation = _AmazingNeoIcons(0xf10c);

  /// map alarm_plus to code point 0xf10d
  static const IconData alarm_plus = _AmazingNeoIcons(0xf10d);

  /// map alarm_snooze to code point 0xf10e
  static const IconData alarm_snooze = _AmazingNeoIcons(0xf10e);

  /// map align_cente to code point 0xf10f
  static const IconData align_cente = _AmazingNeoIcons(0xf10f);

  /// map align_justify to code point 0xf110
  static const IconData align_justify = _AmazingNeoIcons(0xf110);

  /// map align_left to code point 0xf111
  static const IconData align_left = _AmazingNeoIcons(0xf111);

  /// map align_right to code point 0xf112
  static const IconData align_right = _AmazingNeoIcons(0xf112);

  /// map align_slash to code point 0xf113
  static const IconData align_slash = _AmazingNeoIcons(0xf113);

  /// map ambulance to code point 0xf114
  static const IconData ambulance = _AmazingNeoIcons(0xf114);

  /// map analytics to code point 0xf115
  static const IconData analytics = _AmazingNeoIcons(0xf115);

  /// map anchor to code point 0xf116
  static const IconData anchor = _AmazingNeoIcons(0xf116);

  /// map angle_double_down_circle to code point 0xf117
  static const IconData angle_double_down_circle = _AmazingNeoIcons(0xf117);

  /// map angle_double_down_square to code point 0xf118
  static const IconData angle_double_down_square = _AmazingNeoIcons(0xf118);

  /// map angle_double_down to code point 0xf119
  static const IconData angle_double_down = _AmazingNeoIcons(0xf119);

  /// map angle_double_left_circle to code point 0xf11a
  static const IconData angle_double_left_circle = _AmazingNeoIcons(0xf11a);

  /// map angle_double_left_square to code point 0xf11b
  static const IconData angle_double_left_square = _AmazingNeoIcons(0xf11b);

  /// map angle_double_left to code point 0xf11c
  static const IconData angle_double_left = _AmazingNeoIcons(0xf11c);

  /// map angle_double_right_circle to code point 0xf11d
  static const IconData angle_double_right_circle = _AmazingNeoIcons(0xf11d);

  /// map angle_double_right_square to code point 0xf11e
  static const IconData angle_double_right_square = _AmazingNeoIcons(0xf11e);

  /// map angle_double_right to code point 0xf11f
  static const IconData angle_double_right = _AmazingNeoIcons(0xf11f);

  /// map angle_double_up_circle to code point 0xf120
  static const IconData angle_double_up_circle = _AmazingNeoIcons(0xf120);

  /// map angle_double_up_square to code point 0xf121
  static const IconData angle_double_up_square = _AmazingNeoIcons(0xf121);

  /// map angle_double_up to code point 0xf122
  static const IconData angle_double_up = _AmazingNeoIcons(0xf122);

  /// map angle_down_alt_circlebacus to code point 0xf123
  static const IconData angle_down_alt_circlebacus = _AmazingNeoIcons(0xf123);

  /// map angle_down_alt_double_circle to code point 0xf124
  static const IconData angle_down_alt_double_circle = _AmazingNeoIcons(0xf124);

  /// map angle_down_alt_double_square to code point 0xf125
  static const IconData angle_down_alt_double_square = _AmazingNeoIcons(0xf125);

  /// map angle_down_alt_double to code point 0xf126
  static const IconData angle_down_alt_double = _AmazingNeoIcons(0xf126);

  /// map angle_down_alt_square to code point 0xf127
  static const IconData angle_down_alt_square = _AmazingNeoIcons(0xf127);

  /// map angle_down_alt to code point 0xf128
  static const IconData angle_down_alt = _AmazingNeoIcons(0xf128);

  /// map angle_down_circle to code point 0xf129
  static const IconData angle_down_circle = _AmazingNeoIcons(0xf129);

  /// map angle_down_square to code point 0xf12a
  static const IconData angle_down_square = _AmazingNeoIcons(0xf12a);

  /// map angle_dow to code point 0xf12b
  static const IconData angle_dow = _AmazingNeoIcons(0xf12b);

  /// map angle_left_alt_circle to code point 0xf12c
  static const IconData angle_left_alt_circle = _AmazingNeoIcons(0xf12c);

  /// map angle_left_alt_double to code point 0xf12d
  static const IconData angle_left_alt_double = _AmazingNeoIcons(0xf12d);

  /// map angle_left_alt_doublet_circle to code point 0xf12e
  static const IconData angle_left_alt_doublet_circle =
      _AmazingNeoIcons(0xf12e);

  /// map angle_left_alt_doublet_square to code point 0xf12f
  static const IconData angle_left_alt_doublet_square =
      _AmazingNeoIcons(0xf12f);

  /// map angle_left_alt_square to code point 0xf130
  static const IconData angle_left_alt_square = _AmazingNeoIcons(0xf130);

  /// map angle_left_alt to code point 0xf131
  static const IconData angle_left_alt = _AmazingNeoIcons(0xf131);

  /// map angle_left_circle to code point 0xf132
  static const IconData angle_left_circle = _AmazingNeoIcons(0xf132);

  /// map angle_left_square to code point 0xf133
  static const IconData angle_left_square = _AmazingNeoIcons(0xf133);

  /// map angle_left to code point 0xf134
  static const IconData angle_left = _AmazingNeoIcons(0xf134);

  /// map angle_right_alt_circle to code point 0xf135
  static const IconData angle_right_alt_circle = _AmazingNeoIcons(0xf135);

  /// map angle_right_alt_double_circle to code point 0xf136
  static const IconData angle_right_alt_double_circle =
      _AmazingNeoIcons(0xf136);

  /// map angle_right_alt_double_square to code point 0xf137
  static const IconData angle_right_alt_double_square =
      _AmazingNeoIcons(0xf137);

  /// map angle_right_alt_double to code point 0xf138
  static const IconData angle_right_alt_double = _AmazingNeoIcons(0xf138);

  /// map beach to code point 0xf1cb
  static const IconData beach = _AmazingNeoIcons(0xf1cb);

  /// map archive to code point 0xf147
  static const IconData archive = _AmazingNeoIcons(0xf147);

  /// map auto_rickshaw to code point 0xf17f
  static const IconData auto_rickshaw = _AmazingNeoIcons(0xf17f);

  /// map at to code point 0xf17e
  static const IconData at = _AmazingNeoIcons(0xf17e);

  /// map baby to code point 0xf188
  static const IconData baby = _AmazingNeoIcons(0xf188);

  /// map availability to code point 0xf181
  static const IconData availability = _AmazingNeoIcons(0xf181);

  /// map backpac to code point 0xf189
  static const IconData backpac = _AmazingNeoIcons(0xf189);

  /// map barcode to code point 0xf1ad
  static const IconData barcode = _AmazingNeoIcons(0xf1ad);

  /// map battery_empty to code point 0xf1bf
  static const IconData battery_empty = _AmazingNeoIcons(0xf1bf);

  /// map battery_full to code point 0xf1c1
  static const IconData battery_full = _AmazingNeoIcons(0xf1c1);

  /// map book to code point 0xf106
  static const IconData book = _AmazingNeoIcons(0xf106);

  /// map birthday_cake to code point 0xf1d8
  static const IconData birthday_cake = _AmazingNeoIcons(0xf1d8);

  /// map bed_double to code point 0xf1cd
  static const IconData bed_double = _AmazingNeoIcons(0xf1cd);

  /// map bitcoin to code point 0xf1dd
  static const IconData bitcoin = _AmazingNeoIcons(0xf1dd);

  /// map bicycle to code point 0xff1d6
  static const IconData bicycle = _AmazingNeoIcons(0xff1d6);

  /// map bus to code point 0xf228
  static const IconData bus = _AmazingNeoIcons(0xf228);

  /// map calculator_sign to code point 0xf22b
  static const IconData calculator_sign = _AmazingNeoIcons(0xf22b);

  /// map car to code point 0xf243
  static const IconData car = _AmazingNeoIcons(0xf243);

  /// map an_car_wash to code point 0xf248
  static const IconData an_car_wash = _AmazingNeoIcons(0xf248);

  /// map cart to code point 0xf24c
  static const IconData cart = _AmazingNeoIcons(0xf24c);

  /// map cart_plus to code point 0xf250
  static const IconData cart_plus = _AmazingNeoIcons(0xf250);

  /// map chart_line to code point 0xf25d
  static const IconData chart_line = _AmazingNeoIcons(0xf25d);

  /// map chart_bar to code point 0xf25d
  static const IconData chart_bar = _AmazingNeoIcons(0xf25d);

  /// map city to code point 0xf272
  static const IconData city = _AmazingNeoIcons(0xf272);

  /// map cloud_upload to code point 0xf288
  static const IconData cloud_upload = _AmazingNeoIcons(0xf288);

  /// map coffee to code point 0xf295
  static const IconData coffee = _AmazingNeoIcons(0xf295);

  /// map danger to code point 0xf2e7
  static const IconData danger = _AmazingNeoIcons(0xf2e7);

  /// map dance to code point 0xf2e6
  static const IconData dance = _AmazingNeoIcons(0xf2e6);

  /// map diamond to code point 0xf2f1
  static const IconData diamond = _AmazingNeoIcons(0xf2f1);

  /// map dice to code point 0xf2f2
  static const IconData dice = _AmazingNeoIcons(0xf2f2);

  /// map destinatio to code point 0xf2ed
  static const IconData destinatio = _AmazingNeoIcons(0xf2ed);

  /// map eiffel_tower to code point 0xf30f
  static const IconData eiffel_tower = _AmazingNeoIcons(0xf30f);

  /// map fingerprint to code point 0xf36f
  static const IconData fingerprint = _AmazingNeoIcons(0xf36f);

  /// map galaxy to code point 0xf396
  static const IconData galaxy = _AmazingNeoIcons(0xf396);

  /// map glass_chairs to code point 0xf39f
  static const IconData glass_chairs = _AmazingNeoIcons(0xf39f);

  /// map gift to code point 0xf39d
  static const IconData gift = _AmazingNeoIcons(0xf39d);

  /// map gift_card to code point 0xf39d
  static const IconData gift_card = _AmazingNeoIcons(0xf39d);

  /// map graduation_cap to code point 0xf3ae
  static const IconData graduation_cap = _AmazingNeoIcons(0xf3ae);

  /// map guitar to code point 0xf3bc
  static const IconData guitar = _AmazingNeoIcons(0xf3bc);

  /// map hairdryer to code point 0xf3c6
  static const IconData hairdryer = _AmazingNeoIcons(0xf3c6);

  /// map halloween to code point 0xf3c7
  static const IconData halloween = _AmazingNeoIcons(0xf3c7);

  /// map hand to code point 0xf3d1
  static const IconData hand = _AmazingNeoIcons(0xf3d1);

  /// map hand_clap to code point 0xf3ca
  static const IconData hand_clap = _AmazingNeoIcons(0xf3ca);

  /// map kaaba to code point 0xf413
  static const IconData kaaba = _AmazingNeoIcons(0xf413);

  /// map jet to code point 0xf412
  static const IconData jet = _AmazingNeoIcons(0xf412);

  /// map key to code point 0xf414
  static const IconData key = _AmazingNeoIcons(0xf414);

  /// map laptop to code point 0xf420
  static const IconData laptop = _AmazingNeoIcons(0xf420);

  /// map laptop_code to code point 0xf41f
  static const IconData laptop_code = _AmazingNeoIcons(0xf41f);

  /// map landmark to code point 0xf41d
  static const IconData landmark = _AmazingNeoIcons(0xf41d);

  /// map lightbulb_on to code point 0xf42d
  static const IconData lightbulb_on = _AmazingNeoIcons(0xf42d);

  /// map list to code point 0xf43d
  static const IconData list = _AmazingNeoIcons(0xf43d);

  /// map lock to code point 0xf442
  static const IconData lock = _AmazingNeoIcons(0xf442);

  /// map lock_open to code point 0xf444
  static const IconData lock_open = _AmazingNeoIcons(0xf444);

  /// map login to code point 0xf449
  static const IconData login = _AmazingNeoIcons(0xf449);

  /// map logout to code point 0xf44b
  static const IconData logout = _AmazingNeoIcons(0xf44b);

  /// map logout_alt to code point 0xf44a
  static const IconData logout_alt = _AmazingNeoIcons(0xf44a);

  /// map london_eye to code point 0xf44c
  static const IconData london_eye = _AmazingNeoIcons(0xf44c);
}
